/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 1999 - 2005, Digium, Inc.
 *
 * Mark Spencer <markster@digium.com>
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*! \file
 * 
 * \brief Applications connected with Manager engine
 *
 * Mark Spencer <markster@digium.com>
 *
 * \ingroup applications
 */

#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: 61136 $")

#include <sys/types.h>
#include <stdlib.h>

#include "asterisk/channel.h"
#include "asterisk/module.h"
#include "asterisk/pbx.h"

static char *noami_descrip =
"  NoAMI(): This application will tell Asterisk not to send Manager Event for the\n"
"current call.\n";

static char *noami_app = "NoAMI";
static char *noami_synopsis = "Tell Asterisk to not send Manager Event for the current call";


static int noami_exec(struct ast_channel *chan, void *data)
{
	struct ast_module_user *u;
	
	u = ast_module_user_add(chan);

	chan->send_manager = 0;
   
	ast_module_user_remove(u);

	return 0;
}

static int unload_module(void)
{
	int res;

	res = ast_unregister_application(noami_app);

	ast_module_user_hangup_all();

	return res;
}

static int load_module(void)
{
	return ast_register_application(noami_app, noami_exec, noami_synopsis, noami_descrip);
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Tell Asterisk to not send Manager Event for the current call");
